@@ -19,8 +19,6 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-package Dpkg::Deps::Simple;
-
 =encoding utf8
 
 =head1 NAME
@@ -29,7 +27,8 @@ Dpkg::Deps::Simple - represents a single dependency statement
 
 =head1 DESCRIPTION
 
-This object has several interesting properties:
+This class represents a single dependency statement.
+It has several interesting properties:
 
 =over 4
 
@@ -67,17 +66,13 @@ is no restriction formula. Otherwise it is an array ref.
 
 =back
 
-=head1 METHODS
-
-=over 4
-
 =cut
 
+package Dpkg::Deps::Simple 1.02;
+
 use strict;
 use warnings;
 
-our $VERSION = '1.02';
-
 use Carp;
 
 use Dpkg::Arch qw(debarch_is_concerned debarch_list_parse);
@@ -88,7 +83,11 @@ use Dpkg::Gettext;
 
 use parent qw(Dpkg::Interface::Storable);
 
-=item $dep = Dpkg::Deps::Simple->new(%opts);
+=head1 METHODS
+
+=over 4
+
+=item $dep = Dpkg::Deps::Simple->new([$dep[, %opts]]);
 
 Creates a new object. Some options can be set through %opts:
 
@@ -112,6 +111,9 @@ Defaults to 0.
 Specifies whether the parser should consider it a tests dependency.
 Defaults to 0.
 
+This option implicitly (and forcibly) enables C<build_dep> because test
+dependencies are based on build dependencies (since dpkg 1.22.1).
+
 =back
 
 =cut
@@ -127,6 +129,10 @@ sub new {
     $self->{build_arch} = $opts{build_arch};
     $self->{build_dep} = $opts{build_dep} // 0;
     $self->{tests_dep} = $opts{tests_dep} // 0;
+    if ($self->{tests_dep}) {
+        $self->{build_dep} = 1;
+    }
+
     $self->parse_string($arg) if defined $arg;
     return $self;
 }
@@ -149,20 +155,6 @@ sub reset {
     $self->{restrictions} = undef;
 }
 
-=item $dep->parse($fh, $desc)
-
-Parses a line from a filehandle.
-
-=cut
-
-sub parse {
-    my ($self, $fh, $desc) = @_;
-
-    my $line = <$fh>;
-    chomp $line;
-    return $self->parse_string($line);
-}
-
 =item $dep->parse_string($dep_string)
 
 Parses the dependency string and modifies internal properties to match the
@@ -180,6 +172,7 @@ sub parse_string {
         $pkgname_re = qr/[a-zA-Z0-9][a-zA-Z0-9+.-]*/;
     }
 
+    ## no critic (RegularExpressions::ProhibitCaptureWithoutTest)
     return if not $dep =~
            m{^\s*                           # skip leading whitespace
               ($pkgname_re)                 # package name
@@ -224,6 +217,24 @@ sub parse_string {
     }
 }
 
+=item $dep->parse($fh, $desc)
+
+Parse a dependency line from a filehandle.
+
+=cut
+
+sub parse {
+    my ($self, $fh, $desc) = @_;
+
+    my $line = <$fh>;
+    chomp $line;
+    return $self->parse_string($line);
+}
+
+=item $dep->load($filename)
+
+Parse a dependency line from $filename.
+
 =item $dep->output([$fh])
 
 =item "$dep"
@@ -257,6 +268,12 @@ sub output {
     return $res;
 }
 
+=item $dep->save($filename)
+
+Save the dependency into the given $filename.
+
+=cut
+
 # _arch_is_superset(\@p, \@q)
 #
 # Returns true if the arch list @p is a superset of arch list @q.
@@ -267,45 +284,43 @@ sub _arch_is_superset {
     my $p_arch_neg = defined $p and $p->[0] =~ /^!/;
     my $q_arch_neg = defined $q and $q->[0] =~ /^!/;
 
-    # If "p" has no arches, it is a superset of q and we should fall through
-    # to the version check.
     if (not defined $p) {
+        # If "p" has no arches, it is a superset of q and we should fall through
+        # to the version check.
         return 1;
-    }
-    # If q has no arches, it is a superset of p and there are no useful
-    # implications.
-    elsif (not defined $q) {
+    } elsif (not defined $q) {
+        # If q has no arches, it is a superset of p and there are no useful
+        # implications.
         return 0;
-    }
-    # Both have arches.  If neither are negated, we know nothing useful
-    # unless q is a subset of p.
-    elsif (not $p_arch_neg and not $q_arch_neg) {
+    } elsif (not $p_arch_neg and not $q_arch_neg) {
+        # Both have arches.  If neither are negated, we know nothing useful
+        # unless q is a subset of p.
+
         my %p_arches = map { $_ => 1 } @{$p};
         my $subset = 1;
         for my $arch (@{$q}) {
             $subset = 0 unless $p_arches{$arch};
         }
         return 0 unless $subset;
-    }
-    # If both are negated, we know nothing useful unless p is a subset of
-    # q (and therefore has fewer things excluded, and therefore is more
-    # general).
-    elsif ($p_arch_neg and $q_arch_neg) {
+    } elsif ($p_arch_neg and $q_arch_neg) {
+        # If both are negated, we know nothing useful unless p is a subset of
+        # q (and therefore has fewer things excluded, and therefore is more
+        # general).
+
         my %q_arches = map { $_ => 1 } @{$q};
         my $subset = 1;
         for my $arch (@{$p}) {
             $subset = 0 unless $q_arches{$arch};
         }
         return 0 unless $subset;
-    }
-    # If q is negated and p isn't, we'd need to know the full list of
-    # arches to know if there's any relationship, so bail.
-    elsif (not $p_arch_neg and $q_arch_neg) {
+    } elsif (not $p_arch_neg and $q_arch_neg) {
+        # If q is negated and p isn't, we'd need to know the full list of
+        # arches to know if there's any relationship, so bail.
         return 0;
-    }
-    # If p is negated and q isn't, q is a subset of p if none of the
-    # negated arches in p are present in q.
-    elsif ($p_arch_neg and not $q_arch_neg) {
+    } elsif ($p_arch_neg and not $q_arch_neg) {
+        # If p is negated and q isn't, q is a subset of p if none of the
+        # negated arches in p are present in q.
+
         my %q_arches = map { $_ => 1 } @{$q};
         my $subset = 1;
         for my $arch (@{$p}) {
@@ -548,8 +563,8 @@ sub reduce_profiles {
 =item $dep->get_evaluation($facts)
 
 Evaluates the dependency given a list of installed packages and a list of
-virtual packages provided. These lists are part of the Dpkg::Deps::KnownFacts
-object given as parameters.
+virtual packages provided. These lists are part of the
+L<Dpkg::Deps::KnownFacts> object given as parameters.
 
 Returns 1 when it's true, 0 when it's false, undef when some information
 is lacking to conclude.
@@ -566,7 +581,7 @@ sub get_evaluation {
 =item $dep->simplify_deps($facts, @assumed_deps)
 
 Simplifies the dependency as much as possible given the list of facts (see
-object Dpkg::Deps::KnownFacts) and a list of other dependencies that are
+class L<Dpkg::Deps::KnownFacts>) and a list of other dependencies that are
 known to be true.
 
 =cut
